@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
 from django.conf.urls.defaults import *
+from django.contrib.sitemaps import views as sitemaps_views
+from django.views.decorators.cache import cache_page
+
 from rblog.feeds import AllFeed, TagFeed
 from rblog.views import (BlogIndexView,
                          PostDetailView,
@@ -8,8 +11,12 @@ from rblog.views import (BlogIndexView,
                          PostsWithTag,
                          PostsByDate,
                          AJAXArchive,
+                         BlogSitemap,
                          )
-from django.views.decorators.cache import cache_page
+
+sitemaps = {
+    'blog': BlogSitemap,
+}
 
 ctime = (60 * 24 * 7)
 urlpatterns = patterns(
@@ -79,4 +86,10 @@ urlpatterns = patterns(
         cache_page(ctime)(AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
     url(r'^archive/$',
         cache_page(ctime)(AJAXArchive.as_view()), {}, 'app_blog-archive'),
+
+    # sitemap.xml
+    url(r'^sitemap\.xml$',
+        cache_page(ctime)(sitemaps_views.sitemap),
+        {'sitemaps': sitemaps})
+
 )
